import pygame
from pygame.locals import *
from practicum import findDevices
from peri import PeriBoard
from usb import USBError

class SimpleGame(object):
	def __init__(self, title='WalkingHell',
				background_color = pygame.Color('black'), 
				window_size=(1280, 768), 
				fps=60):

		self.title = title
		self.window_size = window_size
		self.fps = fps

		self.is_terminated = False

		self.background_color = background_color
		self.code = []
    
		self.is_restart = False

		self.board = [PeriBoard(findDevices()[0]), PeriBoard(findDevices()[1])]
		self.input_code = 0

		self.checkRelease = False

		self.is_save = False



	def __game_init(self):
		pygame.init()
		self.clock = pygame.time.Clock()
		self.surface = pygame.display.set_mode(self.window_size)
		pygame.display.set_caption(self.title)
		self.font = pygame.font.SysFont("monospace", 20)

	def run(self):
		self.__game_init()
		while not self.is_terminated:
			self.__handle_events()

			self.update()

			self.surface.fill(self.background_color)

			self.render(self.surface)

			pygame.display.update()
			self.clock.tick(self.fps)


	def terminate(self):
		self.is_terminated = True

	def restart(self):
		self.is_restart = True

	def init(self):
		pass

	def update(self):
		pass

	def render(self):
		pass

	def __handle_events(self):
		for i in range(len(self.board)):

			try:
				if self.board[i].getDeviceName() == 'ID 5610502209':
					self.input_code = self.board[i].getSwitch_2()
			except USBError:
				pass

		for event in pygame.event.get():
			if event.type == QUIT:
				self.terminate()
			elif event.type == KEYUP and event.key == K_ESCAPE:
				self.terminate()
			elif event.type == KEYDOWN and event.key == K_r:
				self.restart()
			elif event.type == KEYDOWN and event.key == K_t:
				self.is_save = True
		if len(self.code) < 4:
			if self.input_code == 1 and self.checkRelease:
				self.code.append(1)
				self.checkRelease = False
			elif self.input_code == 2 and self.checkRelease:
				self.code.append(2)
				self.checkRelease = False
			elif self.input_code == 4 and self.checkRelease:
				self.code.append(3)
				self.checkRelease = False
			elif self.input_code == 8 and self.checkRelease:
				self.code.append(4)
				self.checkRelease = False
			elif self.input_code == 16 and self.checkRelease:
				self.code.append(5)
				self.checkRelease = False
			elif self.input_code == 32 and self.checkRelease:
				self.code.append(6)
				self.checkRelease = False
			elif self.input_code == 64 and self.checkRelease:
				self.code.append(7)
				self.checkRelease = False
			elif self.input_code == 128 and self.checkRelease:
				self.code.append(8)
				self.checkRelease = False
			elif self.input_code == 256 and self.checkRelease:
				self.code.append(9)
				self.checkRelease = False
			elif self.input_code == 0 and not self.checkRelease:
				self.checkRelease = True


	

	def on_key_left(self, key):
		print 'left'
 
	def on_key_right(self, key):
		print 'right'