import pygame
from pygame.locals import *
from gamelib import SimpleGame
from player import Player
from management import *
from platform import *
from gameobject import *

class WalkingHell(SimpleGame):
	BLACK = pygame.Color('black')
	WHITE = pygame.Color('white')
	pos_Player = (100, 468)	
	pos_Floor = ((0, 468),(1100, 250),(1750, 168),(2300, -28),(3150, -28),(3250, 350),(3700, 168),(4300, 173),(5000, 168),(5600, 318),(5900, 168),(6400, -532),(6350, -578),
				(7400,  168),(7700, 168),(8400, 168),(9000, 168),(9700, 168),(10350, 200),(11400,250),(12010,300),(12400,320),(13100,400),(13750, 200),(13850, 100),(13950, 0),
				(14050, 100),(15000, 100))
	pos_Box = ((1200, 368),(1180, 150),(2100, 268),(2450, -168),(2750, -168),(4000, 68),(9900, 168),(14170, 0),(14400, 0))
	pos_Thorn = ((5600, 318),(5620, 318),(5640, 318),(5660, 318),(5680, 318),(5700, 318),(5720, 318),(5740, 318),(5760, 318),(5780, 318),(5800, 318),
				(5820, 318),(5840, 318),(5860, 318),(5880, 318),
				(13600, 400),(13620, 400),(13640, 400),(13660, 400),(13680, 400),(13700, 400),(13720, 400),(13740, 400),(13760, 400),(13780, 400),(13800, 400),
				(13820, 400),(13840, 400),(13860, 400),(13880, 400))

	def __init__(self):
		super(WalkingHell, self).__init__(background_color = WalkingHell.BLACK)
		self.player = Player(pos=WalkingHell.pos_Player)
		self.controller = Controller()
		self.platform = [Floor(pos=WalkingHell.pos_Floor[0], weight=1750, height=300, color = pygame.Color('blue')),
						Floor(pos=WalkingHell.pos_Floor[1], weight=350, height=40, color = pygame.Color('red')),
						Floor(pos=WalkingHell.pos_Floor[2], weight=1400, height=600, color = pygame.Color('green')),
						Floor(pos=WalkingHell.pos_Floor[3], weight=660, height=40, color = pygame.Color('white')),
						Floor(pos=WalkingHell.pos_Floor[4], weight=100, height=800, color = pygame.Color('yellow')),
						Floor(pos=WalkingHell.pos_Floor[5], weight=450, height=600, color = pygame.Color('grey')),
						Floor(pos=WalkingHell.pos_Floor[6], weight=600, height=600, color = pygame.Color('purple')),
						FloorSlide(pos=WalkingHell.pos_Floor[7], weight=300, height=40, color = pygame.Color('red'), range_x1 = 4300, range_x2 = 5000),
						Floor(pos=WalkingHell.pos_Floor[8], weight=600, height=600, color = pygame.Color('green')),
						Floor(pos=WalkingHell.pos_Floor[9], weight=300, height=500, color = pygame.Color('blue')),
						Floor(pos=WalkingHell.pos_Floor[10], weight=1500, height=600, color = pygame.Color('grey')),
						Door(pos=WalkingHell.pos_Floor[11], weight=50, height=700, color = pygame.Color('grey'), thick = 0, correctCode = [1,1,1,2], board = self.board),
						Floor(pos=WalkingHell.pos_Floor[12], weight=150, height=600, color = pygame.Color('white'), thick = 0),
						FloorOnDistance(pos=WalkingHell.pos_Floor[13], weight=100, height=40, color = pygame.Color('white'), thick = 5, board = self.board),
						FloorSlide(pos=WalkingHell.pos_Floor[14], weight=300, height=40, color = pygame.Color('red'), range_x1 = 7700, range_x2 = 8400),
						Floor(pos=WalkingHell.pos_Floor[15], weight=600, height=600, color = pygame.Color('white')),
						FloorDelete_X(pos=WalkingHell.pos_Floor[16], weight=600, height=40, color = pygame.Color('green')),
						Floor(pos=WalkingHell.pos_Floor[17], weight=600, height=600, color = pygame.Color('yellow')),
						FloorDelete_X(pos=WalkingHell.pos_Floor[18], weight=1050, height=40, color = pygame.Color('blue')),
						Floor(pos=WalkingHell.pos_Floor[19], weight=600, height=600, color = pygame.Color('red')),
						FloorDelete_X(pos=WalkingHell.pos_Floor[20], weight=390, height=40, color = pygame.Color('blue')),
						FloorSlide(pos=WalkingHell.pos_Floor[21], weight=300, height=40, color = pygame.Color('red'), range_x1 = 12400, range_x2 = 13100),
						Floor(pos=WalkingHell.pos_Floor[22], weight=1900, height=600, color = pygame.Color('purple')),
						Floor(pos=WalkingHell.pos_Floor[23], weight=70, height=40, color = pygame.Color('white')),
						Floor(pos=WalkingHell.pos_Floor[24], weight=70, height=40, color = pygame.Color('grey')),
						Floor(pos=WalkingHell.pos_Floor[25], weight=70, height=40, color = pygame.Color('red')),
						Floor(pos=WalkingHell.pos_Floor[26], weight=600, height=40, color = pygame.Color('black')),
						Floor(pos=WalkingHell.pos_Floor[27], weight=660, height=1200, color = pygame.Color('white'))]


		self.thorn = [Thorn(WalkingHell.pos_Thorn[0]),
					Thorn(WalkingHell.pos_Thorn[1]),
					Thorn(WalkingHell.pos_Thorn[2]),
					Thorn(WalkingHell.pos_Thorn[3]),
					Thorn(WalkingHell.pos_Thorn[4]),
					Thorn(WalkingHell.pos_Thorn[5]),
					Thorn(WalkingHell.pos_Thorn[6]),
					Thorn(WalkingHell.pos_Thorn[7]),
					Thorn(WalkingHell.pos_Thorn[8]),
					Thorn(WalkingHell.pos_Thorn[9]),
					Thorn(WalkingHell.pos_Thorn[10]),
					Thorn(WalkingHell.pos_Thorn[11]),
					Thorn(WalkingHell.pos_Thorn[12]),
					Thorn(WalkingHell.pos_Thorn[13]),
					Thorn(WalkingHell.pos_Thorn[14]),

					Thorn(WalkingHell.pos_Thorn[15]),
					Thorn(WalkingHell.pos_Thorn[16]),
					Thorn(WalkingHell.pos_Thorn[17]),
					Thorn(WalkingHell.pos_Thorn[18]),
					Thorn(WalkingHell.pos_Thorn[19]),
					Thorn(WalkingHell.pos_Thorn[20]),
					Thorn(WalkingHell.pos_Thorn[21]),
					Thorn(WalkingHell.pos_Thorn[22]),
					Thorn(WalkingHell.pos_Thorn[23]),
					Thorn(WalkingHell.pos_Thorn[24]),
					Thorn(WalkingHell.pos_Thorn[25]),
					Thorn(WalkingHell.pos_Thorn[26]),
					Thorn(WalkingHell.pos_Thorn[27]),
					Thorn(WalkingHell.pos_Thorn[28]),
					Thorn(WalkingHell.pos_Thorn[29])]


		self.gameobject = [Stone(WalkingHell.pos_Box[0], 100, 100), Stone(WalkingHell.pos_Box[1], 100, 100), Stone(WalkingHell.pos_Box[2], 100, 100), 
					Stone(WalkingHell.pos_Box[3], 100, 100), Stone(WalkingHell.pos_Box[4], 100, 100), Stone(WalkingHell.pos_Box[5], 100, 100),
					Stone(WalkingHell.pos_Box[6], 100, 100), Stone(WalkingHell.pos_Box[7], 100, 100), Stone(WalkingHell.pos_Box[8], 100, 100)]
		
		cameraOffset = [float(self.window_size[0])/3, float(self.window_size[1])/2]
		self.camera = Camera(offset = cameraOffset)

		self.player_Height = self.player.player_Height
		self.player_Weight = self.player.player_Weight



	def init (self):
		super(WalkingHell, self).init()
		
	def update(self):

		super(WalkingHell, self).update()
		self.controller.controllerPlayer(self.player)
		self.player.update()
		self.controller.updateStatePlayer(self.player)
		if self.controller.collisionEngine(self.player, self.platform, self.gameobject, self.thorn):
			self.is_restart = True

		#------------------------------RestartGame---------------------------------------#
		self.restartGame()

		self.camera.update(playerPosition = [self.player.x, self.player.y])
		for i in range(len(self.gameobject)):
			self.gameobject[i].update()
		for i in range(len(self.platform)):
			if type(self.platform[i]).__name__ == 'Door':
				if self.controller.collisionPlayerinIphone(self.player, self.platform[i]):
					self.platform[i].checkCollisionToCode(True)
					self.platform[i].update(code = self.code)
				else:
					self.platform[i].checkCollisionToCode(False)
					self.code = []
					self.platform[i].update(code = [])
			elif type(self.platform[i]).__name__ == 'FloorOnDistance':
				self.platform[i].update(player = self.player)
			else:
				self.platform[i].update()

		if self.player.y > 1300:
			self.is_restart = True

		if len(self.code) > 3:
			self.code = []

		if self.is_save:
			WalkingHell.pos_Player = (self.player.x, self.player.y)
			WalkingHell.pos_Box = ((self.gameobject[0].x, self.gameobject[0].y),(self.gameobject[1].x, self.gameobject[1].y),(self.gameobject[2].x, self.gameobject[2].y)
										,(self.gameobject[3].x, self.gameobject[3].y),(self.gameobject[4].x, self.gameobject[4].y),(self.gameobject[5].x, self.gameobject[5].y)
										,(self.gameobject[6].x, self.gameobject[6].y),(self.gameobject[7].x, self.gameobject[7].y),(self.gameobject[8].x, self.gameobject[8].y))

			self.is_save = False


	def restartGame(self):
		if self.is_restart:
			#---restart player---#
			self.player.x = WalkingHell.pos_Player[0]
			self.player.y = WalkingHell.pos_Player[1]-300

			#---restart gameobject---#
			for i in range(len(self.gameobject)):
				self.gameobject[i].x = WalkingHell.pos_Box[i][0]
				self.gameobject[i].y = WalkingHell.pos_Box[i][1]

			#---restart platform---#
			for i in range(len(self.platform)):
				if type(self.platform[i]).__name__ == 'Door':
					self.platform[i].is_correctCode = False
				self.platform[i].x = WalkingHell.pos_Floor[i][0]
				self.platform[i].y = WalkingHell.pos_Floor[i][1]
				if type(self.platform[i]).__name__ == 'FloorDelete_X':
					self.platform[i].platform_Weight = self.platform[i].weight_Start
					self.platform[i].platform_Height = self.platform[i].height_Start
					self.platform[i].rectfloor = pygame.Rect(self.platform[i].x, self.platform[i].y, self.platform[i].platform_Weight, self.platform[i].platform_Height)
					self.platform[i].is_Start = False


			for i in range(len(self.board)):
				try:
					if self.board[i].getDeviceName() == 'ID 5610502209':
						self.board[i].setLed(0, 0)
						self.board[i].setLed(1, 0)
						self.board[i].setLed(2, 0)	
				except USBError:
					 pass

			self.code = []

			self.is_restart = False


	def render(self, surface):
		super(WalkingHell, self).render()
		self.renderThorn(surface)
		for i in range(len(self.gameobject)):
			self.gameobject[i].render(surface, posUpdate = self.camera.position)
		self.renderPlatform(surface)
		self.player.render(surface, posUpdate = self.camera.position)

	def renderPlatform(self, surface):
		for i in range(len(self.platform)):
			self.platform[i].render(surface, camPos = self.camera.position)

	def renderThorn(self, surface):
		for i in range(len(self.thorn)):
			self.thorn[i].render(surface, posUpdate = self.camera.position)

def main():
	game = WalkingHell()
	game.run()

if __name__ == '__main__':
	main()