import pygame
from pygame.locals import *
from practicum import findDevices
from peri import PeriBoard
from usb import USBError

class Platform(object):
	def __init__(self, pos, weight, height, color, thick = 5):
		(self.x, self.y) = pos
		self.platform_Weight = weight
		self.platform_Height = height
		self.rectfloor = pygame.Rect(self.x, self.y, self.platform_Weight, self.platform_Height)
		self.color = color
		self.thick = thick
		self.x_Start = self.x
		self.y_Start = self.y
		self.vx = 0

	def init(self):
		pass

	def update(self):
		pass

	def render(self, surface, camPos):
		tempRect = pygame.Rect(self.rectfloor.left - camPos[0], self.rectfloor.top - camPos[1], self.rectfloor.width, self.rectfloor.height)
		pygame.draw.rect(surface,
						self.color,
						tempRect,self.thick)

class Floor(Platform):
	def __init__(self, pos, weight, height, color, thick = 5):
		super(Floor, self).__init__(pos, weight, height, color, thick)

	def update(self):
		pass

	def render(self, surface, camPos):
		super(Floor, self).render(surface, camPos)

class FloorSlide(Platform):
	def __init__(self, pos, weight, height, color, range_x1, range_x2):
		super(FloorSlide, self).__init__(pos, weight, height, color)
		self.range_x1 = range_x1
		self.range_x2 = range_x2
		self.vx = 2

	def update(self):
		if self.x <= self.range_x1:
			self.vx = 2
		elif self.x >= self.range_x2-self.platform_Weight:
			self.vx = -2
		self.x += self.vx
		self.rectfloor = pygame.Rect(self.x, self.y, self.platform_Weight, self.platform_Height)

	def render(self, surface, camPos):
		super(FloorSlide, self).render(surface, camPos)

class Door(Platform):
	def __init__(self, pos, weight, height, color, thick, correctCode, board):
		super(Door, self).__init__(pos, weight, height, color, thick)
		self.x_Start = self.x
		self.y_Start = self.y
		self.correctCode = correctCode
		self.is_correctCode = False
		self.code = []
		self.checkCollision = False
		self.iphone_rect = pygame.Rect(self.x_Start, self.y_Start, 70, 143)

		self.iphone = pygame.image.load('objectPicture/iphone.png')


		self.wrong_code = False
		self.count_wrong = 0

		self.correct_code = True
		self.count_correct = 0
		self.OutOfIphone = False

		self.font = pygame.font.SysFont("monospace", 40)
		self.board = board



	def update(self, code):
		self.code = code
		if self.checkCollision:
			if self.code == self.correctCode:
				self.is_correctCode = True
			elif not self.is_correctCode:
				self.setLedOpen(2, 2, 1)
		else:
			self.setLedOpen(0, 2, 0)
		if self.is_correctCode:
			self.y -= 1
			self.rectfloor = pygame.Rect(self.x, self.y, self.platform_Weight, self.platform_Height)
		else:
			self.y = self.y_Start
			self.rectfloor = pygame.Rect(self.x, self.y, self.platform_Weight, self.platform_Height)
		self.iphone_rect = pygame.Rect(self.x_Start  - 250, self.y_Start + self.platform_Height -143, 70, 143)


	def render(self, surface, camPos):
		
		super(Door, self).render(surface, camPos)
		color = (200,200,0)
		if self.is_correctCode:
			self.text = self.font.render('[' + (' '.join(str(Ccode) for Ccode in self.correctCode) + ']'), True, color)
			surface.blit(self.text,(self.x_Start - camPos[0]-20, self.y_Start - camPos[1] + 720))
			self.correct_code = True
			if self.checkCollision:
				self.setLedOpen(0, 1, 0)
			elif not self.OutOfIphone:
				if self.count_correct > 60:
					self.setLedOpen(0, 0, 0)
					self.count_correct = 0
					self.correct_code = False
					self.OutOfIphone = True
				else:
					self.setLedOpen(0, 1, 0)
					self.count_correct += 1

		elif len(self.code) > 3 and not self.is_correctCode:
			self.wrong_code = True
			self.setLedOpen(1, 0, 2)
		if self.wrong_code:
			if self.count_wrong > 20:
				self.setLedOpen(0, 2, 2)
				self.count_wrong = 0
				self.wrong_code = False
			else:
				self.setLedOpen(1, 2, 2)
				self.count_wrong += 1
		else:
			self.text = self.font.render('[' + (' '.join(str(code) for code in self.code) + ']'), True, color)
			surface.blit(self.text, (self.x_Start - camPos[0]-20, self.y_Start - camPos[1] + 720))
		self.text2 = self.font.render('Pizza Company', True, color)
		surface.blit(self.text2, (self.x_Start - camPos[0]-400, self.y_Start - camPos[1] + 500))
		surface.blit(self.iphone, (self.x_Start - camPos[0] - 250, self.y_Start + self.platform_Height - camPos[1] -143))


	def setLedOpen(self, led_1, led_2, led_3):
		led_all = [led_1, led_2, led_3]
		for i in range(len(self.board)):
			try:
				if self.board[i].getDeviceName() == 'ID 5610502209':
					for j in range(3):
						if led_all[j] != 2:
							self.board[i].setLed(j, led_all[j])	
			except USBError:
				pass

	def checkCollisionToCode(self, checkCollision):
		self.checkCollision = checkCollision

class FloorOnDistance(Platform):
	def __init__(self, pos, weight, height, color, thick, board = 0):
		super(FloorOnDistance, self).__init__(pos, weight, height, color, thick)
		self.countDistance = 0
		self.distance_if = 0
		self.distance = 0
		self.board = board

	def update(self, player):
		if player.x > self.x - 1000 and player.x < self.x + 1000:
			for i in range(len(self.board)):
				try:
					if self.board[i].getDeviceName() == 'ID 5610502209':
						if self.countDistance > 5:
							self.distance_if = self.board[i].getDistance()
							if self.distance_if < 20 and self.distance_if != 0:
								if abs(self.distance_if - self.distance) < 5:
									self.distance = self.distance_if
							self.countDistance = 3
						else:
							self.countDistance += 1
				except USBError:
					pass
		self.x = self.x_Start + self.distance*20
		self.rectfloor = pygame.Rect(self.x, self.y, self.platform_Weight, self.platform_Height)


	def render(self, surface, camPos):
		super(FloorOnDistance, self).render(surface, camPos)

class FloorDelete_X(Platform):
	def __init__(self, pos, weight, height, color, thick = 5):
		super(FloorDelete_X, self).__init__(pos, weight, height, color, thick)
		self.weight_Start = weight
		self.height_Start = height
		self.delete_x = 50
		self.countDelete = 0
		self.is_Start = False

	def update(self):
		if self.is_Start:
			if self.countDelete > 15:
				self.countDelete = 0
				if self.platform_Weight > 50:
					self.platform_Weight -= self.delete_x
					self.x += self.delete_x
				else:
					self.x = -1000

				self.rectfloor = pygame.Rect(self.x, self.y, self.platform_Weight, self.platform_Height)
			else:
				self.countDelete += 1


	def render(self, surface, camPos):
		super(FloorDelete_X, self).render(surface, camPos)