#include <Practicum.h>
#include <NewPing.h>


extern "C" {
#include "usbdrv.h"
}

#define RQ_GET_SWITCH_BOARD1 0
#define RQ_GET_SWITCH_BOARD2 1
#define RQ_GET_LIGHT 2
#define RQ_GET_SONAR 3
#define RQ_GET_LED 4

#define TRIGGER_PIN  PIN_PC1  // Arduino pin tied to trigger pin on the ultrasonic sensor.
#define ECHO_PIN     PIN_PC2  // Arduino pin tied to echo pin on the ultrasonic sensor.
#define MAX_DISTANCE 200 // Maximum distance we want to ping for (in centimeters). Maximum sensor distance is rated at 400-500cm.

    
    
NewPing sonar(TRIGGER_PIN, ECHO_PIN, MAX_DISTANCE); // NewPing setup of pins and maximum distance.
/////////////////////////////////////////////////////////////////////
usbMsgLen_t usbFunctionSetup(uint8_t data[8])
{
  usbRequest_t *rq = (usbRequest_t*)data;
  static uint16_t switch_state;  /* must stay when usbFunctionSetup returns */
  int a = 0,b = 0,c = 0,d = 0,e = 0,f = 0,g = 0,h = 0,i = 0;
  static unsigned int uS;
  
  static uint16_t light;

  
  if (rq->bRequest == RQ_GET_SWITCH_BOARD2)
  {
    a = digitalRead(PIN_PC3) == LOW ? 1:0;
    b = digitalRead(PIN_PC4) == LOW ? 1:0;
    c = digitalRead(PIN_PC5) == LOW ? 1:0;
    d = digitalRead(PIN_PB3) == LOW ? 1:0;
    e = digitalRead(PIN_PB4) == LOW ? 1:0;
    f = digitalRead(PIN_PB5) == LOW ? 1:0;
    g = digitalRead(PIN_PB0) == LOW ? 1:0;
    h = digitalRead(PIN_PB1) == LOW ? 1:0;
    i = digitalRead(PIN_PB2) == LOW ? 1:0;
    
    
    switch_state = a + b*2 + c*4 + d*8 + e*16 + f*32 + g*64 + h*128 + i*256;
    /* point usbMsgPtr to the data to be returned to host */
    usbMsgPtr = (uint8_t*) &switch_state;

    /* return the number of bytes of data to be returned to host */
    return sizeof(switch_state);
  }
  else if (rq->bRequest == RQ_GET_LIGHT)
  {
    light = analogRead(PIN_PC0);
    usbMsgPtr = (uint8_t*) &light;
    return sizeof(light);
  }
  
  
  else if (rq->bRequest == RQ_GET_SONAR)
  {
      uS = sonar.ping() / US_ROUNDTRIP_CM;
      usbMsgPtr = (uint8_t*) &uS;
      return sizeof(uS);
  }
  
  
  else if (rq->bRequest == RQ_GET_LED)
  {
    uint8_t led_val = rq->wValue.bytes[0];
    uint8_t led_no  = rq->wIndex.bytes[0];

    if (led_no == 0)
      digitalWrite(PIN_PD0, led_val);
    else if (led_no == 1)
      digitalWrite(PIN_PD1, led_val);
    else if (led_no == 2)
      digitalWrite(PIN_PD5, led_val);

    return 0;  // return no data back to host
  }
  
  return 0;
}


//////////////////////////////////////////////////////////////////////


void setup()
{
  //light
    pinMode(PIN_PC0, INPUT);
    
  //switch
    pinMode(PIN_PC3, INPUT_PULLUP);
    pinMode(PIN_PC4, INPUT_PULLUP);
    pinMode(PIN_PC5, INPUT_PULLUP);
    pinMode(PIN_PB0, INPUT_PULLUP);
    pinMode(PIN_PB1, INPUT_PULLUP);
    pinMode(PIN_PB2, INPUT_PULLUP);
    pinMode(PIN_PB3, INPUT_PULLUP);
    pinMode(PIN_PB4, INPUT_PULLUP);
    pinMode(PIN_PB5, INPUT_PULLUP);
    
   //led
     pinMode(PIN_PD0, OUTPUT);
     pinMode(PIN_PD1, OUTPUT);
     pinMode(PIN_PD5, OUTPUT);
    usbInit();

    /* enforce re-enumeration of USB devices */
    usbDeviceDisconnect();
    delay(300);
    usbDeviceConnect();
}

//////////////////////////////////////////////////////////////////////
void loop()
{
  usbPoll();
}
